@@ -1,21 +1,17 @@
 from firstimpression.constants import APIS
-from firstimpression.scala import Log
-
-##################################################################################################
-# LOGGING
-##################################################################################################
-
-script = 'default'
-
-info = Log('INFO', script)
-debug = Log('DEBUG', script)
-warn = Log('WARN', script)
-error = Log('ERROR', script)
+from firstimpression.scala import ScalaPlayer
 
 ##################################################################################################
 # CONSTANTS
 ##################################################################################################
 
+NAME = APIS['default']
+
+##################################################################################################
+# Scala Player
+##################################################################################################
+
+scala = ScalaPlayer(NAME)
 
 ##################################################################################################
 # MAIN FUNCTIONS API
