@@ -111,9 +111,9 @@ def check_api():
     keys = svars.keys()
 
     for key in keys:
-        if not 'item' in key:
+        if not 'item' in key and not 'islooping' in key:
             if isinstance(svars[key], bool):
-                if not 'Player' in key and svars[key]:
+                if not 'Player' in key and bool(svars[key]):
                     news_categories.append(key)
 
     for category in news_categories:
