@@ -125,7 +125,7 @@ def run_api():
         params['lon'] = scala.variables['longitude']
         params['lat'] = scala.variables['latitude']
 
-    url_icons = 'http://dev.fi-api.io/weather_images/{}'.format(icon_set)
+    url_icons = 'http://fi-api.io/weather_images/{}'.format(icon_set)
 
     temp_folder_icons = os.path.join(scala.temp_folder, icon_set)
 
