@@ -42,21 +42,28 @@ def run_api():
 
 def check_api():
     timezones = {
+        'auckland': 'Pacific/Auckland',
         'amsterdam': 'Europe/Amsterdam',
-        'berlin': 'Europe/Berlin',
-        'london': 'Europe/London',
-        'new_york': 'America/New_York',
-        'peking': 'Asia/Hong_Kong',
-        'kuala_lumpur': 'Asia/Kuala_Lumpur',
-        'tokyo': 'Asia/Tokyo',
-        'los_angeles': 'America/Los_Angeles',
-        'seattle': 'America/Phoenix',
-        'moscow': 'Europe/Moscow',
-        'dubai': 'Asia/Dubai',
-        'paris': 'Europe/Paris',
-        'taipei': 'Asia/Taipei',
-        'guangzhou': 'Asia/Hong_Kong',
         'bangkok': 'Asia/Bangkok',
+        'calgary': 'America/Edmonton',
+        'dubai': 'Asia/Dubai',
+        'guangzhou': 'Asia/Hong_Kong',
+        'gunzenhausen': 'Europe/Berlin',
+        'hanko': 'Europe/Helsinki',
+        'london': 'Europe/London',
+        'moscow': 'Europe/Moscow',
+        'new_york': 'America/New_York',
+        'nieuwkuijk': 'Europe/Amsterdam',
+        'paris': 'Europe/Paris',
+        'reykjavik': 'Atlantic/Reykjavik',
+        'riyadh': 'Asia/Riyadh',
+        'santiago': 'America/Santiago',
+        'seattle': 'America/Los_Angeles',
+        'shanghai': 'Asia/Shanghai',
+        'stockholm': 'Europe/Stockholm',
+        'sydney': 'Australia/Sydney',
+        'tilburg': 'Europe/Amsterdam',
+        'tokyo': 'Asia/Tokyo',
     }
 
     svars = scala.variables
@@ -69,7 +76,7 @@ def check_api():
 
     for tz in timezones_to_get:
         if tz in timezones.keys():
-            timezones_to_return.append(tz.capitalize())
+            timezones_to_return.append(tz.replace('_', ' ').title())
             images.append('Content:\\{}\\{}.png'.format(NAME, tz.capitalize()))
             times_to_return.append(parse_date_to_string(
                 datetime.datetime.now(pytz.timezone(timezones[tz])), '%H:%M'))
