@@ -1,6 +1,6 @@
 from firstimpression.api.request import give_error_message, request_json
 from firstimpression.constants import IMG_EXTENSIONS, VIDEO_EXTENSIONS
-from firstimpression.file import list_files_dir, purge_directories
+from firstimpression.file import create_directories, list_files_dir, purge_directories
 from firstimpression.scala import ScalaPlayer
 
 
@@ -11,6 +11,7 @@ def update_placeholders():
 
     extensions = IMG_EXTENSIONS + VIDEO_EXTENSIONS
 
+    create_directories([scala.content_folder, scala.temp_folder])
     purge_directories([scala.content_folder, scala.temp_folder], 5)
 
     if len(list_files_dir(scala.content_folder)) == 0:
