@@ -301,7 +301,7 @@ class ScalaPlayer:
         def __len__(self):
             return len(self._item)
 
-        def insert(self, _, __: Any) -> None:
+        def insert(self, index: int, value: Any) -> None:
             self._player.warn(
                 'inserting ScalaScript array items is not allowed')
 
@@ -309,15 +309,15 @@ class ScalaPlayer:
             self._player.warn(
                 'deleting ScalaScript array items is not allowed')
 
-        def extend(self, _) -> None:
+        def extend(self, values: Any) -> None:
             self._player.warn(
                 'extending ScalaScript array items is not allowed')
 
-        def pop(self, _=-1):
+        def pop(self, index: int = -1):
             self._player.warn(
                 'deleting ScalaScript array items is not allowed')
 
-        def remove(self, _):
+        def remove(self, value: Any):
             self._player.warn(
                 'deleting ScalaScript array items is not allowed')
 
